package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.oiw.ElGamalParameter;
import cn.com.infosec.asn1.oiw.OIWObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.PrivateKeyInfo;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.crypto.params.ElGamalPrivateKeyParameters;
import cn.com.infosec.jce.interfaces.ElGamalPrivateKey;
import cn.com.infosec.jce.interfaces.PKCS12BagAttributeCarrier;
import cn.com.infosec.jce.spec.ElGamalParameterSpec;
import cn.com.infosec.jce.spec.ElGamalPrivateKeySpec;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.math.BigInteger;
import java.util.Enumeration;
import javax.crypto.interfaces.DHPrivateKey;
import javax.crypto.spec.DHParameterSpec;
import javax.crypto.spec.DHPrivateKeySpec;

public class JCEElGamalPrivateKey implements ElGamalPrivateKey, DHPrivateKey, PKCS12BagAttributeCarrier {
   static final long serialVersionUID = 4819350091141529678L;
   BigInteger x;
   ElGamalParameterSpec elSpec;
   private PKCS12BagAttributeCarrierImpl attrCarrier;

   protected JCEElGamalPrivateKey() {
      JCEElGamalPrivateKey var10000 = this;
      super();
      PKCS12BagAttributeCarrierImpl var1;
      var1 = new PKCS12BagAttributeCarrierImpl.<init>();
      var10000.attrCarrier = var1;
   }

   JCEElGamalPrivateKey(ElGamalPrivateKey key) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = key.getX();
      this.elSpec = key.getParameters();
   }

   JCEElGamalPrivateKey(DHPrivateKey key) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = key.getX();
      this.elSpec = new ElGamalParameterSpec(key.getParams().getP(), key.getParams().getG());
   }

   JCEElGamalPrivateKey(ElGamalPrivateKeySpec spec) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = spec.getX();
      this.elSpec = new ElGamalParameterSpec(spec.getParams().getP(), spec.getParams().getG());
   }

   JCEElGamalPrivateKey(DHPrivateKeySpec spec) {
      JCEElGamalPrivateKey var10000 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = spec.getX();
      BigInteger var2 = spec.getP();
      var10000.elSpec = new ElGamalParameterSpec(var2, spec.getG());
   }

   JCEElGamalPrivateKey(PrivateKeyInfo info) {
      JCEElGamalPrivateKey var10000 = this;
      JCEElGamalPrivateKey var10001 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      ElGamalParameter var2;
      var2 = new ElGamalParameter.<init>((ASN1Sequence)info.getAlgorithmId().getParameters());
      var10001.x = ((DERInteger)info.getPrivateKey()).getValue();
      ElGamalParameter var10003 = var2;
      BigInteger var3 = var2.getP();
      var10000.elSpec = new ElGamalParameterSpec(var3, var10003.getG());
   }

   JCEElGamalPrivateKey(ElGamalPrivateKeyParameters params) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = params.getX();
      this.elSpec = new ElGamalParameterSpec(params.getParameters().getP(), params.getParameters().getG());
   }

   private void readObject(ObjectInputStream in) {
      this.x = (BigInteger)in.readObject();
      this.elSpec = new ElGamalParameterSpec((BigInteger)in.readObject(), (BigInteger)in.readObject());
   }

   private void writeObject(ObjectOutputStream out) {
      out.writeObject(this.getX());
      out.writeObject(this.elSpec.getP());
      out.writeObject(this.elSpec.getG());
   }

   public String getAlgorithm() {
      return "ElGamal";
   }

   public String getFormat() {
      return "PKCS#8";
   }

   public byte[] getEncoded() {
      return (new PrivateKeyInfo(new AlgorithmIdentifier(OIWObjectIdentifiers.elGamalAlgorithm, (new ElGamalParameter(this.elSpec.getP(), this.elSpec.getG())).getDERObject()), new DERInteger(this.getX()))).getDEREncoded();
   }

   public ElGamalParameterSpec getParameters() {
      return this.elSpec;
   }

   public DHParameterSpec getParams() {
      return new DHParameterSpec(this.elSpec.getP(), this.elSpec.getG());
   }

   public BigInteger getX() {
      return this.x;
   }

   public void setBagAttribute(DERObjectIdentifier oid, DEREncodable attribute) {
      this.attrCarrier.setBagAttribute(oid, attribute);
   }

   public DEREncodable getBagAttribute(DERObjectIdentifier oid) {
      return this.attrCarrier.getBagAttribute(oid);
   }

   public Enumeration getBagAttributeKeys() {
      return this.attrCarrier.getBagAttributeKeys();
   }
}
